@@ -2,7 +2,7 @@
 URL Manager for Django
 """
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __license__ = "MIT"
 __author__ = "Randy Du <randydu@gmail.com>"
 
@@ -11,4 +11,4 @@ from .urlman import mount, url
 def _dump_urls():
     """ dump internal urls (internal) """
     from .urlman import _urls
-    print(*_urls.items())
\ No newline at end of file
+    print(*_urls)
\ No newline at end of file
